@@ -1,5 +1,5 @@
-import unittest
 import os
+import unittest
 
 import badkeys
 
@@ -7,7 +7,6 @@ TDPATH = f"{os.path.dirname(__file__)}/data/"
 
 
 class TestPattern(unittest.TestCase):
-
     def test_roca(self):
         with open(f"{TDPATH}rsa-pattern.key") as f:
             key = f.read()
@@ -19,5 +18,5 @@ class TestPattern(unittest.TestCase):
         self.assertFalse(r["results"])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
